NOTE_EXTENSION = ".an"
STAT_EXTENSION = ".po"

ALLOWED_TYPES = ("epub", "fb2", "pdf", "txt", "zip", "mobi")

DEFAULT_DROPBOX_PATH = "/Books/.Moon+/Cache"

log_format = "%(asctime)-15s %(message)s"
